changeset 34220:3984e8b6d0c5

Fix header and customization.
author Dave Love <fx@gnu.org>
date Tue, 05 Dec 2000 19:18:06 +0000
parents d940776a9d6d
children e31ac0d22ff8
files lisp/gnus/starttls.el
diffstat 1 files changed, 15 insertions(+), 12 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/gnus/starttls.el	Tue Dec 05 19:12:22 2000 +0000
+++ b/lisp/gnus/starttls.el	Tue Dec 05 19:18:06 2000 +0000
@@ -4,19 +4,19 @@
 
 ;; Author: Daiki Ueno <ueno@unixuser.org>
 ;; Created: 1999/11/20
 ;; Keywords: TLS, SSL, OpenSSL
 
-;; This file is not part of any package.
+;; This file is part of GNU Emacs.
 
-;; This program is free software; you can redistribute it and/or
-;; modify it under the terms of the GNU General Public License as
-;; published by the Free Software Foundation; either version 2, or (at
-;; your option) any later version.
+;; GNU Emacs is free software; you can redistribute it and/or modify
+;; it under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 2, or (at your option)
+;; any later version.
 
-;; This program is distributed in the hope that it will be useful, but
-;; WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
+;; GNU Emacs is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
+;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
@@ -34,14 +34,17 @@
 
 (defgroup starttls nil
   "Support for `Transport Layer Security' protocol."
-  :group 'ssl)
+  :version "21.1"
+  :group 'mail)
 
 (defcustom starttls-program "starttls"
   "The program to run in a subprocess to open an TLSv1 connection."
+  :type 'string
   :group 'starttls)
 
 (defcustom starttls-extra-args nil
-  "Extra arguments to `starttls-program'"
+  "Extra arguments to `starttls-program'."
+  :type '(repeat string)
   :group 'starttls)
 
 (defun starttls-negotiate (process)
@@ -4,19 +4,19 @@
 ;; Author: Daiki Ueno <ueno@unixuser.org>
 ;; Created: 1999/11/20
-;; Keywords: TLS, SSL, OpenSSL
+;; Keywords: TLS, SSL, OpenSSL, mail, news
 